import { Transformer } from '../types/transformer';
import { TransformedInput } from '../types/transformed-input';
import { MessengerInterface } from '../types/messenger-interface';
/**
 * Constructor arguments for FileSystemTransformer.
 */
interface FileSystemTransformerConstructorArgs {
    allowedExtensions: string[];
    sourcePath: string;
    messenger?: MessengerInterface;
}
/**
 * Response to read files and transform them to js object
 */
export declare class FileSystemTransformer implements Transformer {
    /**
     * Will convert only those file extensions.
     */
    private readonly allowedExtensions;
    /**
     * The path for the directory with all the icons.
     */
    private readonly sourcePath;
    /**
     * Response for manage logs and errors.
     */
    protected messenger?: MessengerInterface;
    /**
     * Constructor
     *
     * @param allowedExtensions
     * @param sourcePath
     * @param messenger
     */
    constructor({ allowedExtensions, sourcePath, messenger, }: FileSystemTransformerConstructorArgs);
    /**
     * Main class function.
     */
    run(): TransformedInput;
    /**
     * Read icons from directory and return all the icons as property
     * of the final object + svg string as value.
     *
     * @param path
     * @param prefix
     */
    protected readFromDirectory(path: string, prefix?: string): TransformedInput;
}
export {};
