"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileSystemTransformer = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const s_icon_error_1 = require("../errors/s-icon-error");
/**
 * Response to read files and transform them to js object
 */
class FileSystemTransformer {
    /**
     * Constructor
     *
     * @param allowedExtensions
     * @param sourcePath
     * @param messenger
     */
    constructor({ allowedExtensions, sourcePath, messenger, }) {
        this.allowedExtensions = allowedExtensions;
        this.sourcePath = sourcePath;
        this.messenger = messenger;
    }
    /**
     * Main class function.
     */
    run() {
        if (!fs_1.existsSync(this.sourcePath)) {
            throw s_icon_error_1.SIconError.create(`The icons source directory path '${this.sourcePath}' is not exists.`);
        }
        const stats = fs_1.statSync(this.sourcePath);
        if (!stats.isDirectory()) {
            throw s_icon_error_1.SIconError.create(`The icons source path '${this.sourcePath}' must be directory`);
        }
        return this.readFromDirectory(this.sourcePath);
    }
    /**
     * Read icons from directory and return all the icons as property
     * of the final object + svg string as value.
     *
     * @param path
     * @param prefix
     */
    readFromDirectory(path, prefix = '') {
        return fs_1.readdirSync(path).reduce((fileNamesObj, fileName) => {
            const fileFullPath = `${path}/${fileName}`;
            const stats = fs_1.statSync(fileFullPath);
            const ext = path_1.extname(fileFullPath);
            if (stats.isDirectory()) {
                return Object.assign(Object.assign({}, fileNamesObj), this.readFromDirectory(fileFullPath, `${fileName}/`));
            }
            if (!this.allowedExtensions.includes(ext)) {
                return Object.assign({}, fileNamesObj);
            }
            const baseName = path_1.basename(fileName).split('.').slice(0, -1).join('.');
            return Object.assign(Object.assign({}, fileNamesObj), { [`${prefix}${baseName}`]: fs_1.readFileSync(`${path}/${fileName}`).toString('utf-8') });
        }, {});
    }
}
exports.FileSystemTransformer = FileSystemTransformer;
