"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigFactory = void 0;
const fs_1 = require("fs");
const lodash_1 = require("lodash");
const path_1 = require("path");
class ConfigFactory {
    constructor({ defaultConfigPath, messenger }) {
        this.defaultConfigPath = defaultConfigPath;
        this.messenger = messenger;
    }
    /**
     * Read config file,
     * if path is not exists it will try to load from default config path.
     *
     * @param path
     */
    async readConfigFile(path) {
        if (path && !fs_1.existsSync(path)) {
            this.messenger.error(`Config path: '${path}' is not exists.`);
        }
        path = path ? path : this.defaultConfigPath;
        if (!fs_1.existsSync(path)) {
            return {};
        }
        const result = await Promise.resolve().then(() => require(path));
        if (!(result instanceof Object)) {
            return {};
        }
        return result;
    }
    /**
     * Resolve config from an object
     *
     * @param rawConfig
     */
    resolveConfig(rawConfig) {
        return lodash_1.mapValues(lodash_1.pick(rawConfig, ['source', 'destination', 'allowedExtensions']), (value, key) => {
            if (key === 'allowedExtensions' && typeof value === 'string') {
                return lodash_1.split(value, ',');
            }
            if (['source', 'destination'].includes(key)) {
                return path_1.resolve(value);
            }
            return value;
        });
    }
}
exports.ConfigFactory = ConfigFactory;
